# Generated by Django 4.1.5 on 2023-02-15 11:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('project_center', '0002_user_email_notify'),
    ]

    operations = [
        migrations.AddField(
            model_name='projectactivity',
            name='notes',
            field=models.TextField(blank=True, null=True),
        ),
    ]
