# Generated by Django 4.1.7 on 2023-06-04 12:06

from django.db import migrations, models
import project_center.models


class Migration(migrations.Migration):

    dependencies = [
        ('project_center', '0009_projectactivity_reply_file_and_more'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Activity',
        ),
        migrations.AddField(
            model_name='project',
            name='last_activity_date',
            field=models.DateTimeField(blank=True, help_text='Last Activity Date', null=True, verbose_name='Last Activity Date'),
        ),
        migrations.AlterField(
            model_name='projectactivity',
            name='reply',
            field=models.TextField(blank=True, help_text='*** Adding or changing Comments will add a new Activity Record to the Project History', null=True, verbose_name='Comments/Reply'),
        ),
        migrations.AlterField(
            model_name='projectactivity',
            name='reply_file',
            field=models.FileField(blank=True, help_text='*** Attaching a new File will add a new Activity Record to the Project History', null=True, upload_to=project_center.models.activity_file_directory_path, verbose_name='File Attachment'),
        ),
    ]
