# Generated by Django 4.1.7 on 2023-06-05 17:25

from django.db import migrations, models
import project_center.models


class Migration(migrations.Migration):

    dependencies = [
        ('project_center', '0011_project_last_activity_name'),
    ]

    operations = [
        migrations.AlterField(
            model_name='projectactivity',
            name='file',
            field=models.FileField(blank=True, max_length=255, null=True, upload_to=project_center.models.activity_file_directory_path),
        ),
    ]
